==> db4o-5.0-mono.tar.gz: db4o-5.0/src/test/src/com/db4o/test/types/CSharpTypes.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using j4o.lang;
using j4o.util;
namespace com.db4o.test.types {

   public class CSharpTypes: RTest {

       sbyte tsbyte;
       byte tbyte;
       char tchar;              
       short tshort;            
       ushort tushort;          
       int tint;              
       uint tuint; 
       long tlong;
       ulong tulong;
      
      public CSharpTypes() : base() {
      }
      
      public override void set(int ver) {
         if (ver == 1) {
             tsbyte = 1;
             tbyte = 1;
             tchar = (char)1;
             tshort = 1;
             tushort = 1;
             tint = 1;
             tuint = 1;
             tlong = 1;
             tulong = 1;
         } else {
             tsbyte = 2;
             tbyte = 2;
             tchar = (char)2;
             tshort = 2;
             tushort = 2;
             tint = 2;
             tuint = 2;
             tlong = 2;
             tulong = 2;
         }
      }
      
   }
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/test/src/com/db4o/test/types/CSharpTypes.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using j4o.lang;
using j4o.util;
namespace com.db4o.test.types {

   public class CSharpTypes: RTest {

       sbyte tsbyte;
       byte tbyte;
       char tchar;              
       short tshort;            
       ushort tushort;          
       int tint;              
       uint tuint; 
       long tlong;
       ulong tulong;
      
      public CSharpTypes() : base() {
      }
      
      public override void Set(int ver) {
         if (ver == 1) {
             tsbyte = 1;
             tbyte = 1;
             tchar = (char)1;
             tshort = 1;
             tushort = 1;
             tint = 1;
             tuint = 1;
             tlong = 1;
             tulong = 1;
         } else {
             tsbyte = 2;
             tbyte = 2;
             tchar = (char)2;
             tshort = 2;
             tushort = 2;
             tint = 2;
             tuint = 2;
             tlong = 2;
             tulong = 2;
         }
      }
      
   }
}
